# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contek_viper/execution/market_signal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*contek_viper/execution/market_signal.proto\x12\x16\x63ontek_viper.execution\"\x90\x01\n\x0cMarketSignal\x12\x0e\n\x06market\x18\x01 \x01(\t\x12\x0e\n\x06signal\x18\x02 \x01(\x01\x12\x14\n\x0ctrigger_name\x18\x03 \x01(\t\x12\x18\n\x10\x61mplified_signal\x18\x04 \x01(\x01\x12\x12\n\nmultiplier\x18\x05 \x01(\x01\x12\x0b\n\x03\x63\x61p\x18\x06 \x01(\x01\x12\x0f\n\x07\x63ushion\x18\x07 \x01(\x01\x42\x1d\n\x19io.contek.viper.executionP\x01\x62\x06proto3')



_MARKETSIGNAL = DESCRIPTOR.message_types_by_name['MarketSignal']
MarketSignal = _reflection.GeneratedProtocolMessageType('MarketSignal', (_message.Message,), {
  'DESCRIPTOR' : _MARKETSIGNAL,
  '__module__' : 'contek_viper.execution.market_signal_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.MarketSignal)
  })
_sym_db.RegisterMessage(MarketSignal)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.contek.viper.executionP\001'
  _MARKETSIGNAL._serialized_start=71
  _MARKETSIGNAL._serialized_end=215
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

import grpc

from contek_viper.account_session import AccountSession
from contek_viper.execution.execution_service_pb2_grpc import ExecutionServiceStub


class ViperClient:

    def __init__(self, stub: ExecutionServiceStub) -> None:
        self._stub = stub

    @classmethod
    def create(cls, server_address: str) -> ViperClient:
        channel = grpc.insecure_channel(server_address)
        stub = ExecutionServiceStub(channel)
        return cls(stub)

    def session(self, exchange: str, account: str) -> AccountSession:
        return AccountSession(exchange, account, self._stub)



from setuptools import find_packages, setup
from setuptools.command.build_py import build_py


class _BuildProtos(build_py):

    def run(self):
        import build_protos
        build_protos.rebuild()
        build_py.run(self)


setup(
    name='contek-viper',
    version='2.6',
    description='Viper Python Client',
    url='https://contek.io',
    author='contek_bjy',
    author_email='bjy@contek.io',
    license='private',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        'License :: Other/Proprietary License',
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    py_modules=['contek_viper'],
    install_requires=[
        'grpcio',
        'protobuf',
    ],
    setup_requires=['grpcio-tools'],
    cmdclass={'build_py': _BuildProtos},
    zip_safe=True,
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contek_viper/execution/execution_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from contek_viper.execution import market_signal_pb2 as contek__viper_dot_execution_dot_market__signal__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.contek_viper/execution/execution_service.proto\x12\x16\x63ontek_viper.execution\x1a*contek_viper/execution/market_signal.proto\"|\n\x1aSubmitMarketSignalsRequest\x12;\n\rmarket_signal\x18\x01 \x03(\x0b\x32$.contek_viper.execution.MarketSignal\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x03 \x01(\t\"\x1d\n\x1bSubmitMarketSignalsResponse2\x95\x01\n\x10\x45xecutionService\x12\x80\x01\n\x13SubmitMarketSignals\x12\x32.contek_viper.execution.SubmitMarketSignalsRequest\x1a\x33.contek_viper.execution.SubmitMarketSignalsResponse\"\x00\x42\x1d\n\x19io.contek.viper.executionP\x01\x62\x06proto3')



_SUBMITMARKETSIGNALSREQUEST = DESCRIPTOR.message_types_by_name['SubmitMarketSignalsRequest']
_SUBMITMARKETSIGNALSRESPONSE = DESCRIPTOR.message_types_by_name['SubmitMarketSignalsResponse']
SubmitMarketSignalsRequest = _reflection.GeneratedProtocolMessageType('SubmitMarketSignalsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITMARKETSIGNALSREQUEST,
  '__module__' : 'contek_viper.execution.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.SubmitMarketSignalsRequest)
  })
_sym_db.RegisterMessage(SubmitMarketSignalsRequest)

SubmitMarketSignalsResponse = _reflection.GeneratedProtocolMessageType('SubmitMarketSignalsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITMARKETSIGNALSRESPONSE,
  '__module__' : 'contek_viper.execution.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:contek_viper.execution.SubmitMarketSignalsResponse)
  })
_sym_db.RegisterMessage(SubmitMarketSignalsResponse)

_EXECUTIONSERVICE = DESCRIPTOR.services_by_name['ExecutionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.contek.viper.executionP\001'
  _SUBMITMARKETSIGNALSREQUEST._serialized_start=118
  _SUBMITMARKETSIGNALSREQUEST._serialized_end=242
  _SUBMITMARKETSIGNALSRESPONSE._serialized_start=244
  _SUBMITMARKETSIGNALSRESPONSE._serialized_end=273
  _EXECUTIONSERVICE._serialized_start=276
  _EXECUTIONSERVICE._serialized_end=425
# @@protoc_insertion_point(module_scope)



from typing import Iterable

from contek_viper.execution.execution_service_pb2 import SubmitMarketSignalsRequest
from contek_viper.execution.execution_service_pb2_grpc import ExecutionServiceStub
from contek_viper.execution.market_signal_pb2 import MarketSignal


class AccountSession:

    def __init__(
        self,
        exchange: str,
        account: str,
        stub: ExecutionServiceStub,
    ) -> None:
        self._exchange = exchange
        self._account = account
        self._stub = stub

    def submit(self, market_signals: Iterable[MarketSignal]) -> None:
        self._stub.SubmitMarketSignals(
            SubmitMarketSignalsRequest(
                market_signal=list(market_signals),
                exchange=self._exchange,
                account=self._account,
            ))
